==> 0.5.0.tar.gz: arsse/tests/cases/Exception/TestException.php <==
<?php
/** @license MIT
 * Copyright 2017 J. King, Dustin Wilson et al.
 * See LICENSE and AUTHORS files for details */

declare(strict_types=1);
namespace JKingWeb\Arsse\TestCase\Exception;

use JKingWeb\Arsse\Arsse;
use JKingWeb\Arsse\Lang;
use JKingWeb\Arsse\Exception;
use JKingWeb\Arsse\Lang\Exception as LangException;
use Phake;

/** @covers \JKingWeb\Arsse\AbstractException */
class TestException extends \JKingWeb\Arsse\Test\AbstractTest {
    public function setUp() {
        $this->clearData(false);
        // create a mock Lang object so as not to create a dependency loop
        Arsse::$lang = Phake::mock(Lang::class);
        Phake::when(Arsse::$lang)->msg->thenReturn("");
    }

    public function tearDown() {
        // verify calls to the mock Lang object
        Phake::verify(Arsse::$lang, Phake::atLeast(0))->msg($this->isType("string"), $this->anything());
        Phake::verifyNoOtherInteractions(Arsse::$lang);
        // clean up
        $this->clearData(true);
    }

    public function testBaseClass() {
        $this->assertException("unknown");
        throw new Exception("unknown");
    }

    /**
     * @depends testBaseClass
     */
    public function testBaseClassWithoutMessage() {
        $this->assertException("unknown");
        throw new Exception();
    }

    /**
     * @depends testBaseClass
     */
    public function testDerivedClass() {
        $this->assertException("fileMissing", "Lang");
        throw new LangException("fileMissing");
    }

    /**
     * @depends testDerivedClass
     */
    public function testDerivedClassWithMessageParameters() {
        $this->assertException("fileMissing", "Lang");
        throw new LangException("fileMissing", "en");
    }

    /**
     * @depends testBaseClass
     */
    public function testBaseClassWithUnknownCode() {
        $this->assertException("uncoded");
        throw new Exception("testThisExceptionMessageDoesNotExist");
    }

    /**
     * @depends testBaseClassWithUnknownCode
     */
    public function testDerivedClassWithMissingMessage() {
        $this->assertException("uncoded");
        throw new LangException("testThisExceptionMessageDoesNotExist");
    }

    /** @covers \JKingWeb\Arsse\ExceptionFatal */
    public function testFatalException() {
        $this->expectException('JKingWeb\Arsse\ExceptionFatal');
        throw new \JKingWeb\Arsse\ExceptionFatal("");
    }
}

==> 0.7.1.tar.gz: arsse/tests/cases/Exception/TestException.php <==
<?php
/** @license MIT
 * Copyright 2017 J. King, Dustin Wilson et al.
 * See LICENSE and AUTHORS files for details */

declare(strict_types=1);
namespace JKingWeb\Arsse\TestCase\Exception;

use JKingWeb\Arsse\Arsse;
use JKingWeb\Arsse\Lang;
use JKingWeb\Arsse\Exception;
use JKingWeb\Arsse\Lang\Exception as LangException;
use Phake;

/** @covers \JKingWeb\Arsse\AbstractException */
class TestException extends \JKingWeb\Arsse\Test\AbstractTest {
    public function setUp() {
        self::clearData(false);
        // create a mock Lang object so as not to create a dependency loop
        Arsse::$lang = Phake::mock(Lang::class);
        Phake::when(Arsse::$lang)->msg->thenReturn("");
    }

    public function tearDown() {
        // verify calls to the mock Lang object
        Phake::verify(Arsse::$lang, Phake::atLeast(0))->msg($this->isType("string"), $this->anything());
        Phake::verifyNoOtherInteractions(Arsse::$lang);
        // clean up
        self::clearData(true);
    }

    public function testBaseClass() {
        $this->assertException("unknown");
        throw new Exception("unknown");
    }

    /**
     * @depends testBaseClass
     */
    public function testBaseClassWithoutMessage() {
        $this->assertException("unknown");
        throw new Exception();
    }

    /**
     * @depends testBaseClass
     */
    public function testDerivedClass() {
        $this->assertException("fileMissing", "Lang");
        throw new LangException("fileMissing");
    }

    /**
     * @depends testDerivedClass
     */
    public function testDerivedClassWithMessageParameters() {
        $this->assertException("fileMissing", "Lang");
        throw new LangException("fileMissing", "en");
    }

    /**
     * @depends testBaseClass
     */
    public function testBaseClassWithUnknownCode() {
        $this->assertException("uncoded");
        throw new Exception("testThisExceptionMessageDoesNotExist");
    }

    /**
     * @depends testBaseClassWithUnknownCode
     */
    public function testDerivedClassWithMissingMessage() {
        $this->assertException("uncoded");
        throw new LangException("testThisExceptionMessageDoesNotExist");
    }

    /** @covers \JKingWeb\Arsse\ExceptionFatal */
    public function testFatalException() {
        $this->expectException('JKingWeb\Arsse\ExceptionFatal');
        throw new \JKingWeb\Arsse\ExceptionFatal("");
    }
}
